Installing the ASpecD package
=============================

Installing the ASpecD package is as simple as installing any other Python package, as ASpecD is available from the `Python Package Index (PyPI) <https://www.pypi.org/>`_. Simply open a terminal on your computer and type::

  pip install aspecd

This will install the ASpecD package (and all its dependencies) on your computer.

Of course, you need to have Python (and pip) installed before you can use the above command, and it is always advisable to install packages in a virtual environment of their own.

Hence, a more thorough sequence of events would be:

#. Install Python (if it is not already installed on your system).

#. Create a Python virtual environment for ASpecD.

#. Activate the newly created virtual environment.

#. Install ASpecD therein, using the above command.

